@@ -1,14 +1,17 @@
 from typing import List
-from ..config import LennyBotState
-from ..actions import IAction
+
+from ..model.plan import LennyBotPlan
 
 class ApplyService:
 
     def __init__(self) -> None:
         pass
 
-    def apply(self, actions: List[IAction], state: LennyBotState):
-        for action in actions:
+    def apply(self, plan: LennyBotPlan):
+        state=plan.state
+        if not state.is_valid():
+            raise Exception("Invalid State")
+        for action in plan.actions:
             action.run()
             state.update_version(action.application, action.target_version)
         state.save()
\ No newline at end of file
